@@ -128,10 +128,21 @@ panel_utils_show_help (GtkWindow   *parent,
 
 
 gboolean
-panel_utils_grab_available (void)
+panel_utils_grab_available (GtkWidget *widget)
 {
-  /* TODO fix for gtk3 */
-  return TRUE;
+  GdkDisplay* display = gdk_display_get_default ();
+  GdkSeat *seat = gdk_display_get_default_seat (display);
+  GdkWindow *window = gtk_widget_get_window (widget);
+
+  if (xfce_gdk_device_grab (seat, window, GDK_SEAT_CAPABILITY_ALL, NULL) == TRUE)
+    {
+      gdk_seat_ungrab (seat);
+      return TRUE;
+    }
+  else
+    {
+      return FALSE;
+    }
 }
 
 
