@@ -255,17 +255,17 @@ panel_base_window_get_property (GObject    *object,
       break;
 
     case PROP_BACKGROUND_RGBA:
-      if (window->background_rgba != NULL) {
-        rgba = window->background_rgba;
-      }
+      if (window->background_rgba != NULL)
+        g_value_set_boxed (value, window->background_rgba);
       else
         {
           ctx = gtk_widget_get_style_context (GTK_WIDGET (window));
           gtk_style_context_get (ctx, GTK_STATE_FLAG_NORMAL,
                                  GTK_STYLE_PROPERTY_BACKGROUND_COLOR,
                                  &rgba, NULL);
+          g_value_set_boxed (value, rgba);
+          gdk_rgba_free (rgba);
         }
-      g_value_set_boxed (value, rgba);
       break;
 
     case PROP_BACKGROUND_IMAGE:
@@ -301,6 +301,7 @@ panel_base_window_set_property (GObject      *object,
   PanelBaseWindow        *window = PANEL_BASE_WINDOW (object);
   PanelBaseWindowPrivate *priv = window->priv;
   PanelBgStyle            bg_style;
+  GFile                  *file;
 
   switch (prop_id)
     {
@@ -367,9 +368,11 @@ panel_base_window_set_property (GObject      *object,
       break;
 
     case PROP_BACKGROUND_IMAGE:
-      /* store new filename */
+      /* store new uri, built and escaped through a GFile */
       g_free (window->background_image);
-      window->background_image = g_value_dup_string (value);
+      file = g_file_new_for_commandline_arg (g_value_get_string (value));
+      window->background_image = g_file_get_uri (file);
+      g_object_unref (file);
 
       if (window->background_style == PANEL_BG_STYLE_IMAGE)
         {
@@ -607,7 +610,8 @@ static void
 panel_base_window_set_background_color_css (PanelBaseWindow *window) {
   gchar                  *css_string;
   panel_return_if_fail (window->background_rgba != NULL);
-  css_string = g_strdup_printf (".xfce4-panel.background { background-color: %s; border-color: transparent; } %s",
+  css_string = g_strdup_printf (".xfce4-panel.background { background: %s; "
+                                                          "border-color: transparent; } %s",
                                 gdk_rgba_to_string (window->background_rgba),
                                 PANEL_BASE_CSS);
   panel_base_window_set_background_css (window, css_string);
@@ -619,8 +623,7 @@ static void
 panel_base_window_set_background_image_css (PanelBaseWindow *window) {
   gchar                  *css_string;
   panel_return_if_fail (window->background_image != NULL);
-  css_string = g_strdup_printf (".xfce4-panel.background { background-color: transparent;"
-                                                          "background-image: url('%s');"
+  css_string = g_strdup_printf (".xfce4-panel.background { background: url(\"%s\");"
                                                           "border-color: transparent; } %s",
                                 window->background_image, PANEL_BASE_CSS);
   panel_base_window_set_background_css (window, css_string);
