@@ -461,7 +461,6 @@ static void
 directory_menu_plugin_configure_plugin_icon_chooser (GtkWidget           *button,
                                                      DirectoryMenuPlugin *plugin)
 {
-#ifdef EXO_CHECK_VERSION
   GtkWidget *chooser;
   gchar     *icon;
 
@@ -487,7 +486,6 @@ directory_menu_plugin_configure_plugin_icon_chooser (GtkWidget           *button
     }
 
   gtk_widget_destroy (chooser);
-#endif
 }
 
 
@@ -575,13 +573,16 @@ directory_menu_plugin_remote_event (XfcePanelPlugin *panel_plugin,
                                     const GValue    *value)
 {
   DirectoryMenuPlugin *plugin = XFCE_DIRECTORY_MENU_PLUGIN (panel_plugin);
+  GtkWidget *window;
 
   panel_return_val_if_fail (value == NULL || G_IS_VALUE (value), FALSE);
 
+  window = gtk_widget_get_toplevel (GTK_WIDGET (plugin->button));
+
   if (strcmp (name, "popup") == 0
       && gtk_widget_get_visible (GTK_WIDGET (panel_plugin))
       && !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (plugin->button))
-      && panel_utils_grab_available ())
+      && panel_utils_grab_available (window))
     {
       if (value != NULL
           && G_VALUE_HOLDS_BOOLEAN (value)
@@ -831,13 +832,11 @@ directory_menu_plugin_menu_open (GtkWidget   *mi,
     }
 
   if (!result
-#ifdef EXO_CHECK_VERSION
       && !exo_execute_preferred_application_on_screen (category,
                                                        path_as_arg ? working_dir : NULL,
                                                        working_dir,
                                                        NULL,
                                                        gtk_widget_get_screen (mi), &error)
-#endif
      )
     {
       xfce_dialog_show_error (NULL, error,
