@@ -94,9 +94,7 @@ static void               launcher_plugin_menu_popup_destroyed          (gpointe
 static gboolean           launcher_plugin_menu_popup                    (gpointer              user_data);
 static void               launcher_plugin_menu_destroy                  (LauncherPlugin       *plugin);
 static void               launcher_plugin_button_update                 (LauncherPlugin       *plugin);
-#if GARCON_CHECK_VERSION(0,7,0)
 static void               launcher_plugin_button_update_action_menu     (LauncherPlugin       *plugin);
-#endif
 static void               launcher_plugin_button_state_changed          (GtkWidget            *button_a,
                                                                          GtkStateType         state,
                                                                          GtkWidget            *button_b);
@@ -189,9 +187,7 @@ struct _LauncherPlugin
   GtkWidget         *arrow;
   GtkWidget         *child;
   GtkWidget         *menu;
-#if GARCON_CHECK_VERSION(0,7,0)
   GtkWidget         *action_menu;
-#endif
 
   GSList            *items;
 
@@ -337,9 +333,7 @@ launcher_plugin_init (LauncherPlugin *plugin)
   plugin->show_label = FALSE;
   plugin->arrow_position = LAUNCHER_ARROW_DEFAULT;
   plugin->menu = NULL;
-#if GARCON_CHECK_VERSION(0,7,0)
   plugin->action_menu = NULL;
-#endif
   plugin->items = NULL;
   plugin->child = NULL;
   plugin->tooltip_cache = NULL;
@@ -507,9 +501,7 @@ launcher_plugin_item_changed (GarconMenuItem *item,
       if (plugin->items == li)
         {
           launcher_plugin_button_update (plugin);
-#if GARCON_CHECK_VERSION(0,7,0)
           launcher_plugin_button_update_action_menu (plugin);
-#endif
         }
       else
         launcher_plugin_menu_destroy (plugin);
@@ -533,8 +525,6 @@ launcher_plugin_item_duplicate (GFile   *src_file,
   gboolean  result = FALSE;
   gchar    *uri;
 
-  panel_return_val_if_fail (G_IS_FILE (src_file), FALSE);
-  panel_return_val_if_fail (G_IS_FILE (dst_file), FALSE);
   panel_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
   if (!g_file_load_contents (src_file, NULL, &contents, &length, NULL, error))
@@ -551,10 +541,8 @@ launcher_plugin_item_duplicate (GFile   *src_file,
   g_key_file_set_string (key_file, G_KEY_FILE_DESKTOP_GROUP, "X-XFCE-Source", uri);
   g_free (uri);
 
-  contents = g_key_file_to_data (key_file, &length, error);
-  if (contents == NULL)
-    goto err1;
-
+  g_free (contents);
+  contents = g_key_file_to_data (key_file, &length, NULL);
   result = g_file_replace_contents (dst_file, contents, length, NULL, FALSE,
                                     G_FILE_CREATE_REPLACE_DESTINATION,
                                     NULL, NULL, error);
@@ -867,9 +855,7 @@ launcher_plugin_set_property (GObject      *object,
 
       /* update the button */
       launcher_plugin_button_update (plugin);
-#if GARCON_CHECK_VERSION(0,7,0)
       launcher_plugin_button_update_action_menu (plugin);
-#endif
 
       /* update the widget packing */
       goto update_arrow;
@@ -1011,9 +997,7 @@ launcher_plugin_file_changed (GFileMonitor      *monitor,
     {
       launcher_plugin_button_update (plugin);
       launcher_plugin_menu_destroy (plugin);
-#if GARCON_CHECK_VERSION(0,7,0)
       launcher_plugin_button_update_action_menu (plugin);
-#endif
 
       /* save the new config */
       launcher_plugin_save_delayed (plugin);
@@ -1617,10 +1601,12 @@ launcher_plugin_menu_construct (LauncherPlugin *plugin)
   GtkWidget      *mi, *box, *label, *image;
   const gchar    *name, *icon_name;
   GSList         *li;
+  gint            icon_size;
 
   panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
   panel_return_if_fail (plugin->menu == NULL);
 
+  icon_size = xfce_panel_plugin_get_icon_size (XFCE_PANEL_PLUGIN (plugin));
   /* create a new menu */
   plugin->menu = gtk_menu_new ();
   gtk_menu_set_reserve_toggle_size (GTK_MENU (plugin->menu), FALSE);
@@ -1680,22 +1666,22 @@ launcher_plugin_menu_construct (LauncherPlugin *plugin)
       if (panel_str_is_empty (icon_name))
         {
           /* use an empty placeholder icon */
-          image = gtk_image_new_from_icon_name ("", GTK_ICON_SIZE_MENU);
+          image = gtk_image_new_from_icon_name ("", GTK_ICON_SIZE_DND);
         }
       else if (g_path_is_absolute (icon_name))
         {
           /* remember the icon name for recreating the pixbuf when panel
               size changes */
           plugin->icon_name = g_strdup (icon_name);
-          plugin->pixbuf = gdk_pixbuf_new_from_file_at_size (icon_name, 16, 16, NULL);
+          plugin->pixbuf = gdk_pixbuf_new_from_file_at_size (icon_name, icon_size, icon_size, NULL);
           image = gtk_image_new_from_pixbuf (plugin->pixbuf);
         }
       else
         {
-          image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
-          gtk_image_set_pixel_size (GTK_IMAGE (image), 16);
+          image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_DND);
           plugin->icon_name = NULL;
         }
+      gtk_image_set_pixel_size (GTK_IMAGE (image), icon_size);
 
       gtk_box_pack_start (GTK_BOX (box), image, FALSE, TRUE, 3);
       gtk_widget_show (image);
@@ -1870,7 +1856,6 @@ launcher_plugin_button_update (LauncherPlugin *plugin)
 
 
 
-#if GARCON_CHECK_VERSION(0,7,0)
 static void
 launcher_plugin_add_desktop_actions (GtkWidget *widget, gpointer user_data)
 {
@@ -1928,7 +1913,6 @@ launcher_plugin_button_update_action_menu (LauncherPlugin *plugin)
         }
     }
 }
-#endif
 
 
 
