@@ -265,6 +265,16 @@ pager_plugin_set_property (GObject      *object,
     {
     case PROP_WORKSPACE_SCROLLING:
       plugin->scrolling = g_value_get_boolean (value);
+
+#if WNCK_CHECK_VERSION (3, 40, 0)
+      if (plugin->pager != NULL)
+        {
+          wnck_pager_set_scroll_mode (WNCK_PAGER (plugin->pager),
+                                      plugin->scrolling ?
+                                      WNCK_PAGER_SCROLL_1D :
+                                      WNCK_PAGER_SCROLL_NONE);
+        }
+#endif
       break;
 
     case PROP_WRAP_WORKSPACES:
@@ -466,6 +476,12 @@ pager_plugin_screen_layout_changed (PagerPlugin *plugin)
         g_message ("Setting the pager rows returned false. Maybe the setting is not applied.");
 
       wnck_pager_set_orientation (WNCK_PAGER (plugin->pager), orientation);
+#if WNCK_CHECK_VERSION (3, 40, 0)
+      wnck_pager_set_scroll_mode (WNCK_PAGER (plugin->pager),
+                                  plugin->scrolling ?
+                                  WNCK_PAGER_SCROLL_1D :
+                                  WNCK_PAGER_SCROLL_NONE);
+#endif
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       plugin->ratio = (gfloat) gdk_screen_width () / (gfloat) gdk_screen_height ();
 G_GNUC_END_IGNORE_DEPRECATIONS
@@ -511,10 +527,10 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 
       pager_plugin_screen_layout_changed (plugin);
 
-      g_signal_connect_object (G_OBJECT (screen), "monitors-changed",
-         G_CALLBACK (pager_plugin_screen_layout_changed), plugin, G_CONNECT_SWAPPED);
-      g_signal_connect_object (G_OBJECT (screen), "size-changed",
-         G_CALLBACK (pager_plugin_screen_layout_changed), plugin, G_CONNECT_SWAPPED);
+      g_signal_connect_swapped (G_OBJECT (screen), "monitors-changed",
+         G_CALLBACK (pager_plugin_screen_layout_changed), plugin);
+      g_signal_connect_swapped (G_OBJECT (screen), "size-changed",
+         G_CALLBACK (pager_plugin_screen_layout_changed), plugin);
     }
 }
 
@@ -720,18 +736,22 @@ pager_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
                           G_OBJECT (object), "value",
                           G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 
+  plugin->scrolling_switch = gtk_builder_get_object (builder, "workspace-scrolling");
+  panel_return_if_fail (GTK_IS_SWITCH (plugin->scrolling_switch));
+  g_object_bind_property (G_OBJECT (plugin), "workspace-scrolling",
+                          G_OBJECT (plugin->scrolling_switch), "active",
+                          G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+
+#if !(WNCK_CHECK_VERSION (3, 40, 0))
+  g_object_bind_property (G_OBJECT (plugin), "miniature-view",
+                          G_OBJECT (plugin->scrolling_switch), "visible",
+                          G_BINDING_SYNC_CREATE | G_BINDING_DEFAULT | G_BINDING_INVERT_BOOLEAN);
+
   plugin->scrolling_label = gtk_builder_get_object (builder, "workspace-scrolling-label");
   g_object_bind_property (G_OBJECT (plugin), "miniature-view",
                           G_OBJECT (plugin->scrolling_label), "visible",
                           G_BINDING_SYNC_CREATE | G_BINDING_DEFAULT | G_BINDING_INVERT_BOOLEAN);
-  plugin->scrolling_switch = gtk_builder_get_object (builder, "workspace-scrolling");
-  panel_return_if_fail (GTK_IS_SWITCH (plugin->scrolling_switch));
-  g_object_bind_property (G_OBJECT (plugin), "miniature-view",
-                          G_OBJECT (plugin->scrolling_switch), "visible",
-                          G_BINDING_SYNC_CREATE | G_BINDING_DEFAULT | G_BINDING_INVERT_BOOLEAN);
-  g_object_bind_property (G_OBJECT (plugin), "workspace-scrolling",
-                          G_OBJECT (plugin->scrolling_switch), "active",
-                          G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+#endif
 
   plugin->numbering_label = gtk_builder_get_object (builder, "numbering-label");
   g_object_bind_property (G_OBJECT (plugin), "miniature-view",
