@@ -145,6 +145,7 @@ tasklist_plugin_construct (XfcePanelPlugin *panel_plugin)
     { "show-only-minimized", G_TYPE_BOOLEAN },
     { "show-wireframes", G_TYPE_BOOLEAN },
     { "show-handle", G_TYPE_BOOLEAN },
+    { "show-tooltips", G_TYPE_BOOLEAN },
     { "sort-order", G_TYPE_UINT },
     { "window-scrolling", G_TYPE_BOOLEAN },
     { "wrap-windows", G_TYPE_BOOLEAN },
@@ -262,6 +263,7 @@ tasklist_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
   TASKLIST_DIALOG_BIND ("show-only-minimized", "active")
   TASKLIST_DIALOG_BIND ("show-wireframes", "active")
   TASKLIST_DIALOG_BIND ("show-handle", "active")
+  TASKLIST_DIALOG_BIND ("show-tooltips", "active")
   TASKLIST_DIALOG_BIND ("sort-order", "active")
   TASKLIST_DIALOG_BIND ("window-scrolling", "active")
   TASKLIST_DIALOG_BIND ("middle-click", "active")
