@@ -586,13 +586,16 @@ window_menu_plugin_remote_event (XfcePanelPlugin *panel_plugin,
                                  const GValue    *value)
 {
   WindowMenuPlugin *plugin = XFCE_WINDOW_MENU_PLUGIN (panel_plugin);
+  GtkWidget *window;
 
   panel_return_val_if_fail (value == NULL || G_IS_VALUE (value), FALSE);
 
+  window = gtk_widget_get_toplevel (GTK_WIDGET (plugin->button));
+
   if (strcmp (name, "popup") == 0
       && gtk_widget_get_visible (GTK_WIDGET (panel_plugin))
       && !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (plugin->button))
-      && panel_utils_grab_available ())
+      && panel_utils_grab_available (window))
     {
       if (value != NULL
           && G_VALUE_HOLDS_BOOLEAN (value)
@@ -1055,11 +1058,9 @@ G_GNUC_END_IGNORE_DEPRECATIONS
           if (wnck_window_is_minimized (window)
               && plugin->minimized_icon_lucency < 100)
             {
-#ifdef EXO_CHECK_VERSION
               lucent = exo_gdk_pixbuf_lucent (pixbuf, plugin->minimized_icon_lucency);
               if (G_LIKELY (lucent != NULL))
                 pixbuf = lucent;
-#endif
             }
 
           /* set the menu item label */
